"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateCode = exports.init = exports.DEFAULT_TIMEOUT_IN_MS = exports.DEFAULT_WORKER_JS = void 0;
const tslib_1 = require("tslib");
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
const packageVersion = __PACKAGE_VERSION__ || 'latest';
exports.DEFAULT_WORKER_JS = `https://cdn.jsdelivr.net/npm/zwh-lowcode-solution-my-custom-solution@latest/dist/index.js`;
exports.DEFAULT_TIMEOUT_IN_MS = 60 * 1000;
const workerJsCache = new Map();
function init({ workerJsUrl = exports.DEFAULT_WORKER_JS, } = {}) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield loadWorkerJs(workerJsUrl);
    });
}
exports.init = init;
function generateCode(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (typeof self !== 'object') {
            throw new Error('self is not defined');
        }
        if (typeof Worker !== 'function') {
            throw new Error('Worker is not supported');
        }
        const workerJsUrl = options.workerJsUrl || exports.DEFAULT_WORKER_JS;
        const workerJs = yield loadWorkerJs(workerJsUrl);
        const worker = new Worker(workerJs.url, {
            type: 'classic',
            credentials: 'omit',
        });
        return new Promise((resolve, reject) => {
            const timer = setTimeout(() => {
                reject(new Error('timeout'));
                worker.terminate();
            }, options.timeoutInMs || exports.DEFAULT_TIMEOUT_IN_MS);
            worker.onmessage = (event) => {
                const msg = event.data;
                switch (msg.type) {
                    case 'ready':
                        print('worker is ready.');
                        break;
                    case 'run:begin':
                        print('worker is running...');
                        break;
                    case 'run:end':
                        print('worker is done.');
                        resolve(msg.result);
                        clearTimeout(timer);
                        worker.terminate();
                        break;
                    case 'run:error':
                        printErr(`worker error: ${msg.errorMsg}`);
                        clearTimeout(timer);
                        reject(new Error(msg.errorMsg || 'unknown error'));
                        worker.terminate();
                        break;
                    default:
                        print('got unknown msg: %o', msg);
                        break;
                }
            };
            worker.onerror = (err) => {
                printErr('worker error: %o', err);
                clearTimeout(timer);
                reject(err);
                worker.terminate();
            };
            worker.postMessage({
                type: 'run',
                solution: options.solution,
                schema: options.schema,
                flattenResult: options.flattenResult,
            });
        });
    });
}
exports.generateCode = generateCode;
function loadWorkerJs(workerJsUrl) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const cached = workerJsCache.get(workerJsUrl);
        if (cached) {
            return cached;
        }
        const workerJsContent = yield (0, node_fetch_1.default)(workerJsUrl)
            .then((res) => res.text())
            .catch((err) => {
            throw new Error(`Failed to fetch worker js: ${err}`);
        });
        const workerJs = {
            content: workerJsContent,
            url: self.URL.createObjectURL(new self.Blob([workerJsContent], { type: 'application/javascript' })),
        };
        workerJsCache.set(workerJsUrl, workerJs);
        return workerJs;
    });
}
function print(msg, ...args) {
    // eslint-disable-next-line no-console
    console.debug(`[code-generator/loader]: ${msg}`, ...args);
}
function printErr(msg, ...args) {
    // eslint-disable-next-line no-console
    console.debug(`[code-generator/loader]: %c${msg}`, 'color:red', ...args);
}
//# sourceMappingURL=index.js.map