"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const change_case_1 = tslib_1.__importDefault(require("change-case"));
const generator_1 = require("../../../const/generator");
const types_1 = require("../../../types");
const validate_1 = require("../../../utils/validate");
const pluginFactory = () => {
    const plugin = (pre) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const next = Object.assign({}, pre);
        const ir = next.ir;
        // 将模块名转换成 PascalCase 的格式，并添加特定后缀，防止命名冲突
        const componentClassName = (0, validate_1.ensureValidClassName)(`${change_case_1.default.pascalCase(ir.moduleName)}$$${ir.containerType}`);
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.TSX,
            name: generator_1.FUN_DEFINE_CHUNK_NAME.Start,
            content: `const ${componentClassName} = (props) => {`,
            linkAfter: [
                generator_1.COMMON_CHUNK_NAME.ExternalDepsImport,
                generator_1.COMMON_CHUNK_NAME.InternalDepsImport,
                generator_1.COMMON_CHUNK_NAME.ImportAliasDefine,
                generator_1.COMMON_CHUNK_NAME.FileVarDefine,
                generator_1.COMMON_CHUNK_NAME.FileUtilDefine,
            ],
        });
        if (ir.containerType === 'Component') {
            next.chunks.push({
                type: types_1.ChunkType.STRING,
                fileType: types_1.FileType.TSX,
                name: generator_1.FC_DEFINE_CHUNK_NAME.InsVar,
                content: `${componentClassName}.displayName = '${componentClassName}';`,
                linkAfter: [generator_1.FC_DEFINE_CHUNK_NAME.Start],
            });
        }
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.TSX,
            name: generator_1.FUN_DEFINE_CHUNK_NAME.End,
            content: '}',
            linkAfter: [
                ...generator_1.DEFAULT_LINK_AFTER[generator_1.FUN_DEFINE_CHUNK_NAME.End],
                // REACT_CHUNK_NAME.FcRenderEnd,
                // REACT_CHUNK_NAME.FcDidMountEnd,
            ],
        });
        // 构造器暂时不需要？
        /* next.chunks.push({
          type: ChunkType.STRING,
          fileType: FileType.TSX,
          name: FC_DEFINE_CHUNK_NAME.ConstructorStart,
          content: 'constructor(props, context) { super(props); ',
          linkAfter: [...DEFAULT_LINK_AFTER[FC_DEFINE_CHUNK_NAME.ConstructorStart]],
        });
    
        next.chunks.push({
          type: ChunkType.STRING,
          fileType: FileType.TSX,
          name: FC_DEFINE_CHUNK_NAME.ConstructorEnd,
          content: '}',
          linkAfter: [...DEFAULT_LINK_AFTER[FC_DEFINE_CHUNK_NAME.ConstructorEnd]],
        }); */
        // React中的一个hook函数
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.TSX,
            name: generator_1.FUN_DEFINE_CHUNK_NAME.EffectHookStart,
            content: 'useEffect(() => {',
            linkAfter: [...generator_1.DEFAULT_LINK_AFTER[generator_1.FUN_DEFINE_CHUNK_NAME.EffectHookStart]],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.TSX,
            name: generator_1.FUN_DEFINE_CHUNK_NAME.EffectHookEnd,
            content: ' }, []);',
            linkAfter: [
                ...generator_1.DEFAULT_LINK_AFTER[generator_1.FUN_DEFINE_CHUNK_NAME.EffectHookEnd],
                // REACT_CHUNK_NAME.FcDidMountContent,
                // REACT_CHUNK_NAME.FcDidMountStart,
            ],
        });
        // 替换render
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.TSX,
            name: generator_1.FUN_DEFINE_CHUNK_NAME.ReturnStart,
            content: 'return (',
            linkAfter: [
                ...generator_1.DEFAULT_LINK_AFTER[generator_1.FUN_DEFINE_CHUNK_NAME.ReturnStart],
                // REACT_CHUNK_NAME.FcDidMountEnd,
            ],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.TSX,
            name: generator_1.FUN_DEFINE_CHUNK_NAME.ReturnEnd,
            content: ');',
            linkAfter: [
                ...generator_1.DEFAULT_LINK_AFTER[generator_1.FUN_DEFINE_CHUNK_NAME.ReturnEnd],
                // REACT_CHUNK_NAME.FcRenderStart,
                // REACT_CHUNK_NAME.FcRenderPre,
                // REACT_CHUNK_NAME.FcRenderJSX,
            ],
        });
        // 输出 export
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.TSX,
            name: generator_1.COMMON_CHUNK_NAME.FileExport,
            content: `export default ${componentClassName};`,
            linkAfter: [
                generator_1.COMMON_CHUNK_NAME.ExternalDepsImport,
                generator_1.COMMON_CHUNK_NAME.InternalDepsImport,
                generator_1.COMMON_CHUNK_NAME.ImportAliasDefine,
                generator_1.COMMON_CHUNK_NAME.FileVarDefine,
                generator_1.COMMON_CHUNK_NAME.FileUtilDefine,
                // FC_DEFINE_CHUNK_NAME.End,
                generator_1.FUN_DEFINE_CHUNK_NAME.End,
            ],
        });
        return next;
    });
    return plugin;
};
exports.default = pluginFactory;
//# sourceMappingURL=containerClass.js.map