"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const generator_1 = require("../../../const/generator");
const Scope_1 = require("../../../utils/Scope");
const types_1 = require("../../../types");
const const_1 = require("../../../const");
const pluginFactory = (config) => {
    const cfg = Object.assign({ fileType: types_1.FileType.JSX }, config);
    const plugin = (pre) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const next = Object.assign({}, pre);
        const ir = next.ir;
        const scope = Scope_1.Scope.createRootScope();
        const { inStrictMode } = next.contextData;
        if (!inStrictMode) {
            // 非严格模式下，上下文就是自己
            next.chunks.push({
                type: types_1.ChunkType.STRING,
                fileType: cfg.fileType,
                name: generator_1.FC_DEFINE_CHUNK_NAME.InsVar,
                content: `
          _context = this;
        `,
                linkAfter: [generator_1.FC_DEFINE_CHUNK_NAME.Start],
            });
        }
        else {
            // 严格模式下的上下文只保留协议中规定的那些
            next.chunks.push({
                type: types_1.ChunkType.STRING,
                fileType: cfg.fileType,
                name: generator_1.FC_DEFINE_CHUNK_NAME.InsVar,
                content: `
          _context = this._createContext();
        `,
                linkAfter: [generator_1.FC_DEFINE_CHUNK_NAME.Start],
            });
            next.chunks.push({
                type: types_1.ChunkType.STRING,
                fileType: cfg.fileType,
                name: generator_1.FC_DEFINE_CHUNK_NAME.InsPrivateMethod,
                content: `
          _createContext() {
            const self = this;
            const context = {
              get state() { return self.state; },
              setState(newState, callback) { self.setState(newState, callback); },
              get dataSourceMap() { return self._dataSourceEngine.dataSourceMap || {}; },
              async reloadDataSource() { await self._dataSourceEngine.reloadDataSource(); },
              get utils() { return self.utils; },
              get page() { return context; },
              get component() { return context; },
              get props() { return self.props; },
              get constants() { return self.constants; },
              get $() { return self.$ },
              get $$() { return self.$$ },
              ...this._methods,
            };
  
            return context;
          }
        `,
                linkAfter: const_1.DEFAULT_LINK_AFTER[generator_1.FC_DEFINE_CHUNK_NAME.InsPrivateMethod],
            });
        }
        return next;
    });
    return plugin;
};
exports.default = pluginFactory;
//# sourceMappingURL=containerInjectContext.js.map