"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const change_case_1 = tslib_1.__importDefault(require("change-case"));
const generator_1 = require("../../../const/generator");
const const_1 = require("./const");
const types_1 = require("../../../types");
const validate_1 = require("../../../utils/validate");
const pluginFactory = () => {
    const plugin = (pre) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const next = Object.assign({}, pre);
        const ir = next.ir;
        // 将模块名转换成 PascalCase 的格式，并添加特定后缀，防止命名冲突
        const componentClassName = (0, validate_1.ensureValidClassName)(`${change_case_1.default.pascalCase(ir.moduleName)}$$Page`);
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: generator_1.CLASS_DEFINE_CHUNK_NAME.Start,
            content: `class ${componentClassName} extends Component {`,
            linkAfter: [
                generator_1.COMMON_CHUNK_NAME.ExternalDepsImport,
                generator_1.COMMON_CHUNK_NAME.InternalDepsImport,
                generator_1.COMMON_CHUNK_NAME.ImportAliasDefine,
                generator_1.COMMON_CHUNK_NAME.FileVarDefine,
                generator_1.COMMON_CHUNK_NAME.FileUtilDefine,
            ],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: generator_1.CLASS_DEFINE_CHUNK_NAME.End,
            content: '}',
            linkAfter: [
                generator_1.CLASS_DEFINE_CHUNK_NAME.Start,
                generator_1.CLASS_DEFINE_CHUNK_NAME.InsPrivateMethod,
                const_1.RAX_CHUNK_NAME.ClassRenderEnd,
                const_1.RAX_CHUNK_NAME.MethodsEnd,
            ],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: generator_1.CLASS_DEFINE_CHUNK_NAME.ConstructorStart,
            content: 'constructor(props, context) { super(props); ',
            linkAfter: generator_1.DEFAULT_LINK_AFTER[generator_1.CLASS_DEFINE_CHUNK_NAME.ConstructorStart],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: generator_1.CLASS_DEFINE_CHUNK_NAME.ConstructorEnd,
            content: '} /* end of constructor */',
            linkAfter: generator_1.DEFAULT_LINK_AFTER[generator_1.CLASS_DEFINE_CHUNK_NAME.ConstructorEnd],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: const_1.RAX_CHUNK_NAME.ClassDidMountBegin,
            content: 'componentDidMount() {',
            linkAfter: [
                generator_1.CLASS_DEFINE_CHUNK_NAME.Start,
                generator_1.CLASS_DEFINE_CHUNK_NAME.InsVar,
                generator_1.CLASS_DEFINE_CHUNK_NAME.InsMethod,
                generator_1.CLASS_DEFINE_CHUNK_NAME.ConstructorEnd,
            ],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: const_1.RAX_CHUNK_NAME.ClassDidMountEnd,
            content: '} /* end of componentDidMount */',
            linkAfter: [const_1.RAX_CHUNK_NAME.ClassDidMountBegin, const_1.RAX_CHUNK_NAME.ClassDidMountContent],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: const_1.RAX_CHUNK_NAME.ClassWillUnmountBegin,
            content: 'componentWillUnmount() {',
            linkAfter: [
                generator_1.CLASS_DEFINE_CHUNK_NAME.Start,
                generator_1.CLASS_DEFINE_CHUNK_NAME.InsVar,
                generator_1.CLASS_DEFINE_CHUNK_NAME.InsMethod,
                const_1.RAX_CHUNK_NAME.ClassDidMountEnd,
            ],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: const_1.RAX_CHUNK_NAME.ClassWillUnmountEnd,
            content: '} /* end of componentWillUnmount */',
            linkAfter: [const_1.RAX_CHUNK_NAME.ClassWillUnmountBegin, const_1.RAX_CHUNK_NAME.ClassWillUnmountContent],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: const_1.RAX_CHUNK_NAME.ClassRenderBegin,
            content: 'render() {',
            linkAfter: [const_1.RAX_CHUNK_NAME.ClassDidMountEnd, const_1.RAX_CHUNK_NAME.ClassWillUnmountEnd],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: const_1.RAX_CHUNK_NAME.ClassRenderEnd,
            content: '} /* end of render */',
            linkAfter: [
                const_1.RAX_CHUNK_NAME.ClassRenderBegin,
                const_1.RAX_CHUNK_NAME.ClassRenderPre,
                const_1.RAX_CHUNK_NAME.ClassRenderJSX,
            ],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JSX,
            name: generator_1.COMMON_CHUNK_NAME.FileExport,
            content: `export default ${componentClassName};`,
            linkAfter: [
                generator_1.COMMON_CHUNK_NAME.ExternalDepsImport,
                generator_1.COMMON_CHUNK_NAME.InternalDepsImport,
                generator_1.COMMON_CHUNK_NAME.ImportAliasDefine,
                generator_1.COMMON_CHUNK_NAME.FileVarDefine,
                generator_1.COMMON_CHUNK_NAME.FileUtilDefine,
                generator_1.CLASS_DEFINE_CHUNK_NAME.End,
            ],
        });
        return next;
    });
    return plugin;
};
exports.default = pluginFactory;
//# sourceMappingURL=containerClass.js.map