"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
const lowcode_types_1 = require("@alilc/lowcode-types");
const generator_1 = require("../../../const/generator");
const const_1 = require("./const");
const types_1 = require("../../../types");
const debug_1 = require("../../../utils/debug");
const common_1 = require("../../../utils/common");
const pluginFactory = (config) => {
    const cfg = Object.assign({ fileType: types_1.FileType.JSX, exportNameMapping: {}, normalizeNameMapping: {
            didMount: 'componentDidMount',
            willUnmount: 'componentWillUnmount',
        } }, config);
    const exportNameMapping = new Map(Object.entries(cfg.exportNameMapping));
    const normalizeNameMapping = new Map(Object.entries(cfg.normalizeNameMapping));
    const plugin = (pre) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const next = Object.assign({}, pre);
        // Rax 先只支持 didMount 和 willUnmount 吧
        const ir = next.ir;
        const { lifeCycles } = ir;
        if (lifeCycles && !lodash_1.default.isEmpty(lifeCycles)) {
            Object.entries(lifeCycles).forEach(([lifeCycleName, lifeCycleMethodExpr]) => {
                // 过滤掉非法数据（有些场景下会误传入空字符串或 null)
                if (!(0, lowcode_types_1.isJSFunction)(lifeCycles[lifeCycleName]) &&
                    !(0, common_1.isJSExpressionFn)(lifeCycles[lifeCycleName]) &&
                    !(0, lowcode_types_1.isJSExpression)(lifeCycles[lifeCycleName])) {
                    return;
                }
                const normalizeName = normalizeNameMapping.get(lifeCycleName) || lifeCycleName;
                const exportName = exportNameMapping.get(lifeCycleName) || lifeCycleName;
                next.chunks.push({
                    type: types_1.ChunkType.STRING,
                    fileType: cfg.fileType,
                    name: const_1.RAX_CHUNK_NAME.LifeCyclesContent,
                    content: `${exportName}: (${lifeCycleMethodExpr.value}),`,
                    linkAfter: [const_1.RAX_CHUNK_NAME.LifeCyclesBegin],
                });
                if (normalizeName === 'constructor') {
                    next.chunks.push({
                        type: types_1.ChunkType.STRING,
                        fileType: cfg.fileType,
                        name: generator_1.CLASS_DEFINE_CHUNK_NAME.ConstructorContent,
                        content: `this._lifeCycles.${exportName}();`,
                        linkAfter: [generator_1.CLASS_DEFINE_CHUNK_NAME.ConstructorStart],
                    });
                }
                else if (normalizeName === 'componentDidMount') {
                    next.chunks.push({
                        type: types_1.ChunkType.STRING,
                        fileType: cfg.fileType,
                        name: const_1.RAX_CHUNK_NAME.ClassDidMountContent,
                        content: `this._lifeCycles.${exportName}();`,
                        linkAfter: [const_1.RAX_CHUNK_NAME.ClassDidMountBegin],
                    });
                }
                else if (normalizeName === 'componentWillUnmount') {
                    next.chunks.push({
                        type: types_1.ChunkType.STRING,
                        fileType: cfg.fileType,
                        name: const_1.RAX_CHUNK_NAME.ClassWillUnmountContent,
                        content: `this._lifeCycles.${exportName}();`,
                        linkAfter: [const_1.RAX_CHUNK_NAME.ClassWillUnmountBegin],
                    });
                }
                else {
                    (0, debug_1.debug)(`[CodeGen]: unknown life cycle: ${lifeCycleName}`);
                }
            });
            next.chunks.push({
                type: types_1.ChunkType.STRING,
                fileType: cfg.fileType,
                name: generator_1.CLASS_DEFINE_CHUNK_NAME.InsVar,
                content: '_lifeCycles = this._defineLifeCycles();',
                linkAfter: [generator_1.CLASS_DEFINE_CHUNK_NAME.Start],
            });
            next.chunks.push({
                type: types_1.ChunkType.STRING,
                fileType: cfg.fileType,
                name: const_1.RAX_CHUNK_NAME.LifeCyclesBegin,
                content: `
          _defineLifeCycles() {
            const __$$lifeCycles = ({
        `,
                linkAfter: [const_1.RAX_CHUNK_NAME.ClassRenderEnd, generator_1.CLASS_DEFINE_CHUNK_NAME.InsPrivateMethod],
            });
            next.chunks.push({
                type: types_1.ChunkType.STRING,
                fileType: cfg.fileType,
                name: const_1.RAX_CHUNK_NAME.LifeCyclesEnd,
                content: `
            });

            // 为所有的方法绑定上下文
            Object.entries(__$$lifeCycles).forEach(([lifeCycleName, lifeCycleMethod]) => {
              if (typeof lifeCycleMethod === 'function') {
                __$$lifeCycles[lifeCycleName] = (...args) => {
                  return lifeCycleMethod.apply(this._context, args);
                }
              }
            });

            return __$$lifeCycles;
          }
        `,
                linkAfter: [const_1.RAX_CHUNK_NAME.LifeCyclesBegin, const_1.RAX_CHUNK_NAME.LifeCyclesContent],
            });
        }
        return next;
    });
    return plugin;
};
exports.default = pluginFactory;
//# sourceMappingURL=containerLifeCycle.js.map