"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const generator_1 = require("../../../const/generator");
const jsExpression_1 = require("../../../utils/jsExpression");
const types_1 = require("../../../types");
const validate_1 = require("../../../utils/validate");
const pluginFactory = (config) => {
    const cfg = Object.assign({ fileType: types_1.FileType.JSX }, config);
    const plugin = (pre) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const next = Object.assign({}, pre);
        const ir = next.ir;
        const { inStrictMode } = next.contextData;
        if (!ir.methods) {
            return next;
        }
        // 将这些 methods 都定义到 class 上
        const { methods } = ir;
        const chunks = Object.keys(methods).map((methodName) => ({
            type: types_1.ChunkType.STRING,
            fileType: cfg.fileType,
            name: generator_1.CLASS_DEFINE_CHUNK_NAME.InsMethod,
            content: (0, jsExpression_1.generateFunction)(methods[methodName], { name: methodName, isMember: true }),
            linkAfter: [...generator_1.DEFAULT_LINK_AFTER[generator_1.CLASS_DEFINE_CHUNK_NAME.InsMethod]],
        }));
        next.chunks.push(...chunks);
        // 严格模式下需要将这些方法都挂到上下文中
        if (inStrictMode) {
            next.chunks.push({
                type: types_1.ChunkType.STRING,
                fileType: cfg.fileType,
                name: generator_1.CLASS_DEFINE_CHUNK_NAME.ConstructorContent,
                content: Object.keys(ir.methods)
                    .map((methodName) => (0, validate_1.isValidIdentifier)(methodName) ? `.${methodName}` : `[${JSON.stringify(methodName)}]`)
                    .map((method) => `this._context${method} = this${method};`)
                    .join('\n'),
                linkAfter: [...generator_1.DEFAULT_LINK_AFTER[generator_1.CLASS_DEFINE_CHUNK_NAME.ConstructorContent]],
            });
        }
        return next;
    });
    return plugin;
};
exports.default = pluginFactory;
//# sourceMappingURL=containerMethod.js.map