"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const generator_1 = require("../../const/generator");
const types_1 = require("../../types");
const pluginFactory = (baseFramework) => {
    const plugin = (pre) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const framework = baseFramework || 'react';
        const next = Object.assign({}, pre);
        const ir = next.ir;
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JS,
            name: generator_1.COMMON_CHUNK_NAME.ExternalDepsImport,
            content: `
        import { createRef } from '${framework}';
      `,
            linkAfter: [],
        });
        next.chunks.push({
            type: types_1.ChunkType.STRING,
            fileType: types_1.FileType.JS,
            name: generator_1.COMMON_CHUNK_NAME.FileUtilDefine,
            content: `
        export class RefsManager {
          constructor() {
            this.refInsStore = {};
          }

          clearNullRefs() {
            Object.keys(this.refInsStore).forEach((refName) => {
              const filteredInsList = this.refInsStore[refName].filter(insRef => !!insRef.current);
              if (filteredInsList.length > 0) {
                this.refInsStore[refName] = filteredInsList;
              } else {
                delete this.refInsStore[refName];
              }
            });
          }

          get(refName) {
            this.clearNullRefs();
            if (this.refInsStore[refName] && this.refInsStore[refName].length > 0) {
              return this.refInsStore[refName][0].current;
            }

            return null;
          }

          getAll(refName) {
            this.clearNullRefs();
            if (this.refInsStore[refName] && this.refInsStore[refName].length > 0) {
              return this.refInsStore[refName].map(i => i.current);
            }

            return [];
          }

          linkRef(refName) {
            const refIns = createRef();
            this.refInsStore[refName] = this.refInsStore[refName] || [];
            this.refInsStore[refName].push(refIns);
            return refIns;
          }
        }
      `,
            linkAfter: [...generator_1.DEFAULT_LINK_AFTER[generator_1.COMMON_CHUNK_NAME.FileUtilDefine]],
        });
        if (ir.utils) {
            next.chunks.push({
                type: types_1.ChunkType.STRING,
                fileType: types_1.FileType.JS,
                name: generator_1.COMMON_CHUNK_NAME.FileExport,
                content: `
          export default {
        `,
                linkAfter: [
                    generator_1.COMMON_CHUNK_NAME.ExternalDepsImport,
                    generator_1.COMMON_CHUNK_NAME.InternalDepsImport,
                    generator_1.COMMON_CHUNK_NAME.ImportAliasDefine,
                    generator_1.COMMON_CHUNK_NAME.FileVarDefine,
                    generator_1.COMMON_CHUNK_NAME.FileUtilDefine,
                    generator_1.COMMON_CHUNK_NAME.FileMainContent,
                ],
            });
            ir.utils.forEach((util) => {
                if (util.type === 'function') {
                    next.chunks.push({
                        type: types_1.ChunkType.STRING,
                        fileType: types_1.FileType.JS,
                        name: generator_1.COMMON_CHUNK_NAME.FileVarDefine,
                        content: `
              const ${util.name} = ${util.content.value};
            `,
                        linkAfter: [
                            generator_1.COMMON_CHUNK_NAME.ExternalDepsImport,
                            generator_1.COMMON_CHUNK_NAME.InternalDepsImport,
                            generator_1.COMMON_CHUNK_NAME.ImportAliasDefine,
                        ],
                    });
                }
                next.chunks.push({
                    type: types_1.ChunkType.STRING,
                    fileType: types_1.FileType.JS,
                    name: generator_1.COMMON_CHUNK_NAME.FileExport,
                    content: `${util.name},`,
                    linkAfter: [
                        generator_1.COMMON_CHUNK_NAME.ExternalDepsImport,
                        generator_1.COMMON_CHUNK_NAME.InternalDepsImport,
                        generator_1.COMMON_CHUNK_NAME.ImportAliasDefine,
                        generator_1.COMMON_CHUNK_NAME.FileVarDefine,
                        generator_1.COMMON_CHUNK_NAME.FileUtilDefine,
                        generator_1.COMMON_CHUNK_NAME.FileMainContent,
                    ],
                });
            });
            next.chunks.push({
                type: types_1.ChunkType.STRING,
                fileType: types_1.FileType.JS,
                name: generator_1.COMMON_CHUNK_NAME.FileExport,
                content: `
          };
        `,
                linkAfter: [
                    generator_1.COMMON_CHUNK_NAME.ExternalDepsImport,
                    generator_1.COMMON_CHUNK_NAME.InternalDepsImport,
                    generator_1.COMMON_CHUNK_NAME.ImportAliasDefine,
                    generator_1.COMMON_CHUNK_NAME.FileVarDefine,
                    generator_1.COMMON_CHUNK_NAME.FileUtilDefine,
                    generator_1.COMMON_CHUNK_NAME.FileMainContent,
                ],
            });
        }
        return next;
    });
    return plugin;
};
exports.default = pluginFactory;
//# sourceMappingURL=utils.js.map