"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeFolder = void 0;
const tslib_1 = require("tslib");
const systemFs = tslib_1.__importStar(require("fs"));
const path_1 = require("path");
const writeFolder = (folder, currentPath, createProjectFolder = true, fs = systemFs) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const { name, files, dirs } = folder;
    const folderPath = createProjectFolder ? (0, path_1.join)(currentPath, name) : currentPath;
    if (!fs.existsSync(folderPath)) {
        yield createDirectory(folderPath, fs);
    }
    const promises = [
        writeFilesToFolder(folderPath, files, fs),
        writeSubFoldersToFolder(folderPath, dirs, fs),
    ];
    yield Promise.all(promises);
});
exports.writeFolder = writeFolder;
const writeFilesToFolder = (folderPath, files, fs) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const promises = files.map((file) => {
        const fileName = file.ext ? `${file.name}.${file.ext}` : file.name;
        const filePath = (0, path_1.join)(folderPath, fileName);
        return writeContentToFile(filePath, file.content, 'utf8', fs);
    });
    yield Promise.all(promises);
});
const writeSubFoldersToFolder = (folderPath, subFolders, fs) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const promises = subFolders.map((subFolder) => {
        return (0, exports.writeFolder)(subFolder, folderPath, true, fs);
    });
    yield Promise.all(promises);
});
const createDirectory = (pathToDir, fs) => {
    return new Promise((resolve, reject) => {
        fs.mkdir(pathToDir, { recursive: true }, (err) => {
            err ? reject(err) : resolve();
        });
    });
};
const writeContentToFile = (filePath, fileContent, encoding = 'utf8', fs) => {
    return new Promise((resolve, reject) => {
        fs.writeFile(filePath, fileContent, { encoding: encoding }, (err) => {
            err ? reject(err) : resolve();
        });
    });
};
//# sourceMappingURL=utils.js.map