"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createZipPublisher = void 0;
const tslib_1 = require("tslib");
const types_1 = require("../../types");
const errors_1 = require("../../utils/errors");
const utils_1 = require("./utils");
const createZipPublisher = (params = {}) => {
    let { project, outputPath } = params;
    const getProject = () => project;
    const setProject = (projectToSet) => {
        project = projectToSet;
    };
    const getOutputPath = () => outputPath;
    const setOutputPath = (path) => {
        outputPath = path;
    };
    const publish = (options = {}) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const projectToPublish = options.project || project;
        if (!projectToPublish) {
            throw new types_1.PublisherError('MissingProject');
        }
        const zipName = options.projectSlug || params.projectSlug || projectToPublish.name;
        try {
            const zipContent = yield (0, utils_1.generateProjectZip)(projectToPublish);
            // If not output path is provided, zip is not written to disk
            const projectOutputPath = options.outputPath || outputPath;
            if (projectOutputPath && (0, utils_1.isNodeProcess)()) {
                yield (0, utils_1.writeZipToDisk)(projectOutputPath, zipContent, zipName);
            }
            return { success: true, payload: zipContent };
        }
        catch (error) {
            throw new types_1.PublisherError((0, errors_1.getErrorMessage)(error) || 'UnknownError');
        }
    });
    return {
        publish,
        getProject,
        setProject,
        getOutputPath,
        setOutputPath,
    };
};
exports.createZipPublisher = createZipPublisher;
//# sourceMappingURL=index.js.map