"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateProjectZip = exports.writeZipToDisk = exports.isNodeProcess = void 0;
const tslib_1 = require("tslib");
const jszip_1 = tslib_1.__importDefault(require("jszip"));
const isNodeProcess = () => {
    return (typeof process === 'object' &&
        typeof process.versions === 'object' &&
        typeof process.versions.node !== 'undefined');
};
exports.isNodeProcess = isNodeProcess;
const writeZipToDisk = (zipFolderPath, content, zipName) => {
    if (!(0, exports.isNodeProcess)()) {
        throw new Error('ZipPublisher: writeZipToDisk is only available in NodeJS');
    }
    // eslint-disable-next-line @typescript-eslint/no-var-requires
    // eslint-disable-next-line @typescript-eslint/no-require-imports
    const fs = require('fs');
    // eslint-disable-next-line @typescript-eslint/no-var-requires
    // eslint-disable-next-line @typescript-eslint/no-require-imports
    const path = require('path');
    if (!fs.existsSync(zipFolderPath)) {
        fs.mkdirSync(zipFolderPath, { recursive: true });
    }
    const zipPath = path.join(zipFolderPath, `${zipName}.zip`);
    const writeStream = fs.createWriteStream(zipPath);
    writeStream.write(content);
    writeStream.end();
};
exports.writeZipToDisk = writeZipToDisk;
const generateProjectZip = (project) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    let zip = new jszip_1.default();
    zip = writeFolderToZip(project, zip, true);
    // const zipType = isNodeProcess() ? 'nodebuffer' : 'blob';
    const zipType = 'nodebuffer'; // 目前先只支持 node 调用
    return zip.generateAsync({ type: zipType });
});
exports.generateProjectZip = generateProjectZip;
const writeFolderToZip = (folder, parentFolder, ignoreFolder = false) => {
    const zipFolder = ignoreFolder ? parentFolder : parentFolder.folder(folder.name);
    if (zipFolder !== null) {
        folder.files.forEach((file) => {
            // const options = file.contentEncoding === 'base64' ? { base64: true } : {};
            const options = {};
            const fileName = file.ext ? `${file.name}.${file.ext}` : file.name;
            zipFolder.file(fileName, file.content, options);
        });
        folder.dirs.forEach((subFolder) => {
            writeFolderToZip(subFolder, zipFolder);
        });
    }
    return parentFolder;
};
//# sourceMappingURL=utils.js.map