"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.plugins = void 0;
const tslib_1 = require("tslib");
const ProjectBuilder_1 = require("../generator/ProjectBuilder");
const esmodule_1 = tslib_1.__importDefault(require("../plugins/common/esmodule"));
const styleImport_1 = tslib_1.__importDefault(require("../plugins/common/styleImport"));
const containerClass_1 = tslib_1.__importDefault(require("../plugins/component/react/containerClass"));
const containerInitState_1 = tslib_1.__importDefault(require("../plugins/component/react/containerInitState"));
const containerInjectContext_1 = tslib_1.__importDefault(require("../plugins/component/react/containerInjectContext"));
const containerInjectUtils_1 = tslib_1.__importDefault(require("../plugins/component/react/containerInjectUtils"));
const containerInjectDataSourceEngine_1 = tslib_1.__importDefault(require("../plugins/component/react/containerInjectDataSourceEngine"));
const containerInjectConstants_1 = tslib_1.__importDefault(require("../plugins/component/react/containerInjectConstants"));
const containerInjectI18n_1 = tslib_1.__importDefault(require("../plugins/component/react/containerInjectI18n"));
const containerLifeCycle_1 = tslib_1.__importDefault(require("../plugins/component/react/containerLifeCycle"));
const containerMethod_1 = tslib_1.__importDefault(require("../plugins/component/react/containerMethod"));
const jsx_1 = tslib_1.__importDefault(require("../plugins/component/react/jsx"));
const reactCommonDeps_1 = tslib_1.__importDefault(require("../plugins/component/react/reactCommonDeps"));
const css_1 = tslib_1.__importDefault(require("../plugins/component/style/css"));
const constants_1 = tslib_1.__importDefault(require("../plugins/project/constants"));
const i18n_1 = tslib_1.__importDefault(require("../plugins/project/i18n"));
const utils_1 = tslib_1.__importDefault(require("../plugins/project/utils"));
const icejs_1 = tslib_1.__importDefault(require("../plugins/project/framework/icejs"));
const postprocessor_1 = require("../postprocessor");
function createIceJsProjectBuilder(options) {
    return (0, ProjectBuilder_1.createProjectBuilder)({
        inStrictMode: options === null || options === void 0 ? void 0 : options.inStrictMode,
        extraContextData: Object.assign({}, options),
        template: icejs_1.default.template,
        plugins: {
            components: [
                (0, reactCommonDeps_1.default)(),
                (0, esmodule_1.default)({
                    fileType: 'jsx',
                }),
                (0, styleImport_1.default)(),
                (0, containerClass_1.default)(),
                (0, containerInjectContext_1.default)(),
                (0, containerInjectUtils_1.default)(),
                (0, containerInjectDataSourceEngine_1.default)(),
                (0, containerInjectI18n_1.default)(),
                (0, containerInjectConstants_1.default)(),
                (0, containerInitState_1.default)(),
                (0, containerLifeCycle_1.default)(),
                (0, containerMethod_1.default)(),
                (0, jsx_1.default)({
                    nodeTypeMapping: {
                        Div: 'div',
                        Component: 'div',
                        Page: 'div',
                        Block: 'div',
                    },
                }),
                (0, css_1.default)(),
            ],
            pages: [
                (0, reactCommonDeps_1.default)(),
                (0, esmodule_1.default)({
                    fileType: 'jsx',
                }),
                (0, styleImport_1.default)(),
                (0, containerClass_1.default)(),
                (0, containerInjectContext_1.default)(),
                (0, containerInjectUtils_1.default)(),
                (0, containerInjectDataSourceEngine_1.default)(),
                (0, containerInjectI18n_1.default)(),
                (0, containerInjectConstants_1.default)(),
                (0, containerInitState_1.default)(),
                (0, containerLifeCycle_1.default)(),
                (0, containerMethod_1.default)(),
                (0, jsx_1.default)({
                    nodeTypeMapping: {
                        Div: 'div',
                        Component: 'div',
                        Page: 'div',
                        Block: 'div',
                        // Box: 'div',
                    },
                }),
                (0, css_1.default)(),
            ],
            router: [(0, esmodule_1.default)(), icejs_1.default.plugins.router()],
            entry: [icejs_1.default.plugins.entry()],
            constants: [(0, constants_1.default)()],
            utils: [(0, esmodule_1.default)(), (0, utils_1.default)('react')],
            i18n: [(0, i18n_1.default)()],
            globalStyle: [icejs_1.default.plugins.globalStyle()],
            htmlEntry: [icejs_1.default.plugins.entryHtml()],
            packageJSON: [icejs_1.default.plugins.packageJSON()],
        },
        postProcessors: [(0, postprocessor_1.prettier)()],
        customizeBuilderOptions: options === null || options === void 0 ? void 0 : options.customizeBuilderOptions,
    });
}
exports.default = createIceJsProjectBuilder;
exports.plugins = {
    containerClass: containerClass_1.default,
    containerInjectContext: containerInjectContext_1.default,
    containerInjectUtils: containerInjectUtils_1.default,
    containerInjectDataSourceEngine: containerInjectDataSourceEngine_1.default,
    containerInjectI18n: containerInjectI18n_1.default,
    containerInjectConstants: containerInjectConstants_1.default,
    containerInitState: containerInitState_1.default,
    containerLifeCycle: containerLifeCycle_1.default,
    containerMethod: containerMethod_1.default,
    jsx: jsx_1.default,
    commonDeps: reactCommonDeps_1.default,
    /** @deprecated Please use commonDeps */
    reactCommonDeps: reactCommonDeps_1.default,
};
//# sourceMappingURL=icejs.js.map