"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.plugins = void 0;
const tslib_1 = require("tslib");
const ProjectBuilder_1 = require("../generator/ProjectBuilder");
const esmodule_1 = tslib_1.__importDefault(require("../plugins/common/esmodule"));
const containerClass_1 = tslib_1.__importDefault(require("../plugins/component/rax/containerClass"));
const containerLifeCycle_1 = tslib_1.__importDefault(require("../plugins/component/rax/containerLifeCycle"));
const containerMethods_1 = tslib_1.__importDefault(require("../plugins/component/rax/containerMethods"));
const containerInitState_1 = tslib_1.__importDefault(require("../plugins/component/rax/containerInitState"));
const containerInjectContext_1 = tslib_1.__importDefault(require("../plugins/component/rax/containerInjectContext"));
const containerInjectDataSourceEngine_1 = tslib_1.__importDefault(require("../plugins/component/rax/containerInjectDataSourceEngine"));
const containerInjectUtils_1 = tslib_1.__importDefault(require("../plugins/component/rax/containerInjectUtils"));
const jsx_1 = tslib_1.__importDefault(require("../plugins/component/rax/jsx"));
const commonDeps_1 = tslib_1.__importDefault(require("../plugins/component/rax/commonDeps"));
const css_1 = tslib_1.__importDefault(require("../plugins/component/style/css"));
const constants_1 = tslib_1.__importDefault(require("../plugins/project/constants"));
const i18n_1 = tslib_1.__importDefault(require("../plugins/project/i18n"));
const utils_1 = tslib_1.__importDefault(require("../plugins/project/utils"));
const rax_1 = tslib_1.__importDefault(require("../plugins/project/framework/rax"));
const postprocessor_1 = require("../postprocessor");
function createRaxProjectBuilder(options) {
    return (0, ProjectBuilder_1.createProjectBuilder)({
        inStrictMode: options === null || options === void 0 ? void 0 : options.inStrictMode,
        extraContextData: Object.assign({}, options),
        template: rax_1.default.template,
        plugins: {
            components: [
                (0, commonDeps_1.default)(),
                (0, esmodule_1.default)({ fileType: 'jsx', useAliasName: false }),
                (0, containerClass_1.default)(),
                (0, containerInitState_1.default)(),
                (0, containerMethods_1.default)(),
                (0, containerInjectContext_1.default)(),
                (0, containerInjectDataSourceEngine_1.default)(options),
                (0, containerInjectUtils_1.default)(),
                (0, containerLifeCycle_1.default)(),
                (0, jsx_1.default)(),
                (0, css_1.default)(),
            ],
            pages: [
                (0, commonDeps_1.default)(),
                (0, esmodule_1.default)({ fileType: 'jsx' }),
                (0, containerClass_1.default)(),
                (0, containerInitState_1.default)(),
                (0, containerMethods_1.default)(),
                (0, containerInjectContext_1.default)(),
                (0, containerInjectDataSourceEngine_1.default)(options),
                (0, containerInjectUtils_1.default)(),
                (0, containerLifeCycle_1.default)(),
                (0, jsx_1.default)(),
                (0, css_1.default)(),
            ],
            appConfig: [rax_1.default.plugins.appConfig(options)],
            buildConfig: [rax_1.default.plugins.buildConfig(options)],
            entry: [rax_1.default.plugins.entry(options)],
            constants: [(0, constants_1.default)()],
            utils: [(0, esmodule_1.default)(), (0, utils_1.default)('rax')],
            i18n: [(0, i18n_1.default)()],
            globalStyle: [
                rax_1.default.plugins.globalStyle({ fileType: (options === null || options === void 0 ? void 0 : options.globalStylesFileType) || 'css' }),
            ],
            htmlEntry: [rax_1.default.plugins.entryDocument(options)],
            packageJSON: [rax_1.default.plugins.packageJSON(options)],
        },
        postProcessors: [(0, postprocessor_1.prettier)()],
        customizeBuilderOptions: options === null || options === void 0 ? void 0 : options.customizeBuilderOptions,
    });
}
exports.default = createRaxProjectBuilder;
exports.plugins = {
    containerClass: containerClass_1.default,
    containerLifeCycles: containerLifeCycle_1.default,
    containerMethods: containerMethods_1.default,
    containerInitState: containerInitState_1.default,
    containerInjectContext: containerInjectContext_1.default,
    containerInjectDataSourceEngine: containerInjectDataSourceEngine_1.default,
    containerInjectUtils: containerInjectUtils_1.default,
    jsx: jsx_1.default,
    commonDeps: commonDeps_1.default,
    raxApp: rax_1.default,
};
//# sourceMappingURL=rax-app.js.map