export const COMMON_CHUNK_NAME = {
  ExternalDepsImport: 'CommonExternalDependencyImport',
  InternalDepsImport: 'CommonInternalDependencyImport',
  ImportAliasDefine: 'CommonImportAliasDefine',
  FileVarDefine: 'CommonFileScopeVarDefine',
  FileUtilDefine: 'CommonFileScopeMethodDefine',
  FileMainContent: 'CommonFileMainContent',
  FileExport: 'CommonFileExport',
  StyleDepsImport: 'CommonStyleDepsImport',
  StyleCssContent: 'CommonStyleCssContent',
  HtmlContent: 'CommonHtmlContent',
  CustomContent: 'CommonCustomContent',
};

export const CLASS_DEFINE_CHUNK_NAME = {
  Start: 'CommonClassDefineStart',
  ConstructorStart: 'CommonClassDefineConstructorStart',
  ConstructorContent: 'CommonClassDefineConstructorContent',
  ConstructorEnd: 'CommonClassDefineConstructorEnd',
  StaticVar: 'CommonClassDefineStaticVar',
  StaticMethod: 'CommonClassDefineStaticMethod',
  InsVar: 'CommonClassDefineInsVar',
  InsVarMethod: 'CommonClassDefineInsVarMethod',
  InsMethod: 'CommonClassDefineInsMethod',
  InsPrivateMethod: 'CommonClassDefineInsPrivateMethod',
  End: 'CommonClassDefineEnd',
};

export const FC_DEFINE_CHUNK_NAME = {
  Start: 'CommonFcDefineStart',
  ConstructorStart: 'CommonFcDefineConstructorStart',
  ConstructorContent: 'CommonFcDefineConstructorContent',
  ConstructorEnd: 'CommonFcDefineConstructorEnd',
  StaticVar: 'CommonFcDefineStaticVar',
  StaticMethod: 'CommonFcDefineStaticMethod',
  InsVar: 'CommonFcDefineInsVar',
  InsVarMethod: 'CommonFcDefineInsVarMethod',
  InsMethod: 'CommonFcDefineInsMethod',
  InsPrivateMethod: 'CommonFcDefineInsPrivateMethod',
  Hooks: 'CommonFunState',
  End: 'CommonFcDefineEnd',
};

export const FUN_DEFINE_CHUNK_NAME = {
  Start: 'CommonFunDefineStart',
  InsVar: 'CommonFunDefineInsVar',
  StateHook: 'CommonFunDefineStateHook',
  EffectHookStart: 'CommonFunDefineEffectHookStart',
  EffectHookContent: 'CommonFunDefineEffectHookContent',
  EffectHookEnd: 'CommonFunDefineEffectHookEnd',
  InsMethod: 'CommonFunDefineInsMethod',
  ReturnStart: 'CommonFunDefineReturnStart',
  JSX: 'CommonFunDefineJSX',
  ReturnEnd: 'CommonFunDefineReturnEnd',
  End: 'CommonFunDefineEnd',
};

export const DEFAULT_LINK_AFTER = {
  [COMMON_CHUNK_NAME.ExternalDepsImport]: [],
  [COMMON_CHUNK_NAME.InternalDepsImport]: [
    COMMON_CHUNK_NAME.ExternalDepsImport,
  ],
  [COMMON_CHUNK_NAME.ImportAliasDefine]: [
    COMMON_CHUNK_NAME.ExternalDepsImport,
    COMMON_CHUNK_NAME.InternalDepsImport,
  ],
  [COMMON_CHUNK_NAME.FileVarDefine]: [
    COMMON_CHUNK_NAME.ExternalDepsImport,
    COMMON_CHUNK_NAME.InternalDepsImport,
    COMMON_CHUNK_NAME.ImportAliasDefine,
  ],
  [COMMON_CHUNK_NAME.FileUtilDefine]: [
    COMMON_CHUNK_NAME.ExternalDepsImport,
    COMMON_CHUNK_NAME.InternalDepsImport,
    COMMON_CHUNK_NAME.ImportAliasDefine,
    COMMON_CHUNK_NAME.FileVarDefine,
  ],
  [CLASS_DEFINE_CHUNK_NAME.Start]: [
    COMMON_CHUNK_NAME.ExternalDepsImport,
    COMMON_CHUNK_NAME.InternalDepsImport,
    COMMON_CHUNK_NAME.ImportAliasDefine,
    COMMON_CHUNK_NAME.FileVarDefine,
    COMMON_CHUNK_NAME.FileUtilDefine,
  ],

  [CLASS_DEFINE_CHUNK_NAME.ConstructorStart]: [
    CLASS_DEFINE_CHUNK_NAME.Start,
    CLASS_DEFINE_CHUNK_NAME.StaticVar,
    CLASS_DEFINE_CHUNK_NAME.StaticMethod,
    CLASS_DEFINE_CHUNK_NAME.InsVar,
    CLASS_DEFINE_CHUNK_NAME.InsVarMethod,
  ],

  [CLASS_DEFINE_CHUNK_NAME.ConstructorContent]: [
    CLASS_DEFINE_CHUNK_NAME.ConstructorStart,
  ],
  [CLASS_DEFINE_CHUNK_NAME.ConstructorEnd]: [
    CLASS_DEFINE_CHUNK_NAME.ConstructorStart,
    CLASS_DEFINE_CHUNK_NAME.ConstructorContent,
  ],

  [CLASS_DEFINE_CHUNK_NAME.StaticVar]: [CLASS_DEFINE_CHUNK_NAME.Start],
  [CLASS_DEFINE_CHUNK_NAME.StaticMethod]: [
    CLASS_DEFINE_CHUNK_NAME.Start,
    CLASS_DEFINE_CHUNK_NAME.StaticVar,
  ],

  [CLASS_DEFINE_CHUNK_NAME.InsVar]: [
    CLASS_DEFINE_CHUNK_NAME.Start,
    CLASS_DEFINE_CHUNK_NAME.StaticVar,
    CLASS_DEFINE_CHUNK_NAME.StaticMethod,
  ],
  [CLASS_DEFINE_CHUNK_NAME.InsVarMethod]: [
    CLASS_DEFINE_CHUNK_NAME.Start,
    CLASS_DEFINE_CHUNK_NAME.StaticVar,
    CLASS_DEFINE_CHUNK_NAME.StaticMethod,
    CLASS_DEFINE_CHUNK_NAME.InsVar,
  ],
  [CLASS_DEFINE_CHUNK_NAME.InsMethod]: [
    CLASS_DEFINE_CHUNK_NAME.Start,
    CLASS_DEFINE_CHUNK_NAME.StaticVar,
    CLASS_DEFINE_CHUNK_NAME.StaticMethod,
    CLASS_DEFINE_CHUNK_NAME.InsVar,
    CLASS_DEFINE_CHUNK_NAME.InsVarMethod,
    CLASS_DEFINE_CHUNK_NAME.ConstructorEnd,
  ],
  [CLASS_DEFINE_CHUNK_NAME.InsPrivateMethod]: [
    CLASS_DEFINE_CHUNK_NAME.Start,
    CLASS_DEFINE_CHUNK_NAME.StaticVar,
    CLASS_DEFINE_CHUNK_NAME.StaticMethod,
    CLASS_DEFINE_CHUNK_NAME.InsVar,
    CLASS_DEFINE_CHUNK_NAME.InsVarMethod,
    CLASS_DEFINE_CHUNK_NAME.InsMethod,
    CLASS_DEFINE_CHUNK_NAME.ConstructorEnd,
  ],
  [CLASS_DEFINE_CHUNK_NAME.End]: [
    CLASS_DEFINE_CHUNK_NAME.Start,
    CLASS_DEFINE_CHUNK_NAME.StaticVar,
    CLASS_DEFINE_CHUNK_NAME.StaticMethod,
    CLASS_DEFINE_CHUNK_NAME.InsVar,
    CLASS_DEFINE_CHUNK_NAME.InsVarMethod,
    CLASS_DEFINE_CHUNK_NAME.InsMethod,
    CLASS_DEFINE_CHUNK_NAME.InsPrivateMethod,
    CLASS_DEFINE_CHUNK_NAME.ConstructorEnd,
  ],

  // 添加FC
  // 标记 state（hooks）在
  [FUN_DEFINE_CHUNK_NAME.InsVar]: [FUN_DEFINE_CHUNK_NAME.Start],
  [FUN_DEFINE_CHUNK_NAME.StateHook]: [
    FUN_DEFINE_CHUNK_NAME.Start,
    FUN_DEFINE_CHUNK_NAME.InsVar,
  ],
  [FUN_DEFINE_CHUNK_NAME.EffectHookStart]: [
    FUN_DEFINE_CHUNK_NAME.Start,
    FUN_DEFINE_CHUNK_NAME.InsVar,
    FUN_DEFINE_CHUNK_NAME.StateHook,
  ],
  [FUN_DEFINE_CHUNK_NAME.EffectHookContent]: [
    FUN_DEFINE_CHUNK_NAME.Start,
    FUN_DEFINE_CHUNK_NAME.InsVar,
    FUN_DEFINE_CHUNK_NAME.StateHook,
    FUN_DEFINE_CHUNK_NAME.EffectHookStart,
  ],
  [FUN_DEFINE_CHUNK_NAME.EffectHookEnd]: [
    FUN_DEFINE_CHUNK_NAME.Start,
    FUN_DEFINE_CHUNK_NAME.InsVar,
    FUN_DEFINE_CHUNK_NAME.StateHook,
    FUN_DEFINE_CHUNK_NAME.EffectHookStart,
    FUN_DEFINE_CHUNK_NAME.EffectHookContent,
  ],
  [FUN_DEFINE_CHUNK_NAME.InsMethod]: [
    FUN_DEFINE_CHUNK_NAME.Start,
    FUN_DEFINE_CHUNK_NAME.InsVar,
    FUN_DEFINE_CHUNK_NAME.StateHook,
    FUN_DEFINE_CHUNK_NAME.EffectHookStart,
    FUN_DEFINE_CHUNK_NAME.EffectHookContent,
    FUN_DEFINE_CHUNK_NAME.EffectHookEnd,
  ],
  [FUN_DEFINE_CHUNK_NAME.ReturnStart]: [
    FUN_DEFINE_CHUNK_NAME.Start,
    FUN_DEFINE_CHUNK_NAME.InsVar,
    FUN_DEFINE_CHUNK_NAME.StateHook,
    FUN_DEFINE_CHUNK_NAME.EffectHookStart,
    FUN_DEFINE_CHUNK_NAME.EffectHookContent,
    FUN_DEFINE_CHUNK_NAME.EffectHookEnd,
    FUN_DEFINE_CHUNK_NAME.InsMethod,
  ],
  [FUN_DEFINE_CHUNK_NAME.JSX]: [
    FUN_DEFINE_CHUNK_NAME.Start,
    FUN_DEFINE_CHUNK_NAME.InsVar,
    FUN_DEFINE_CHUNK_NAME.StateHook,
    FUN_DEFINE_CHUNK_NAME.EffectHookStart,
    FUN_DEFINE_CHUNK_NAME.EffectHookContent,
    FUN_DEFINE_CHUNK_NAME.EffectHookEnd,
    FUN_DEFINE_CHUNK_NAME.InsMethod,
    FUN_DEFINE_CHUNK_NAME.ReturnStart,
  ],
  [FUN_DEFINE_CHUNK_NAME.ReturnEnd]: [
    FUN_DEFINE_CHUNK_NAME.Start,
    FUN_DEFINE_CHUNK_NAME.InsVar,
    FUN_DEFINE_CHUNK_NAME.StateHook,
    FUN_DEFINE_CHUNK_NAME.EffectHookStart,
    FUN_DEFINE_CHUNK_NAME.EffectHookContent,
    FUN_DEFINE_CHUNK_NAME.EffectHookEnd,
    FUN_DEFINE_CHUNK_NAME.InsMethod,
    FUN_DEFINE_CHUNK_NAME.ReturnStart,
    FUN_DEFINE_CHUNK_NAME.JSX,
  ],
  [FUN_DEFINE_CHUNK_NAME.End]: [
    FUN_DEFINE_CHUNK_NAME.Start,
    FUN_DEFINE_CHUNK_NAME.InsVar,
    FUN_DEFINE_CHUNK_NAME.StateHook,
    FUN_DEFINE_CHUNK_NAME.EffectHookStart,
    FUN_DEFINE_CHUNK_NAME.EffectHookContent,
    FUN_DEFINE_CHUNK_NAME.EffectHookEnd,
    FUN_DEFINE_CHUNK_NAME.InsMethod,
    FUN_DEFINE_CHUNK_NAME.ReturnStart,
    FUN_DEFINE_CHUNK_NAME.JSX,
    FUN_DEFINE_CHUNK_NAME.ReturnEnd,
  ],

  [FC_DEFINE_CHUNK_NAME.ConstructorStart]: [
    FC_DEFINE_CHUNK_NAME.Start,
    FC_DEFINE_CHUNK_NAME.StaticVar,
    FC_DEFINE_CHUNK_NAME.StaticMethod,
    FC_DEFINE_CHUNK_NAME.InsVar,
    FC_DEFINE_CHUNK_NAME.InsVarMethod,
  ],
  [FC_DEFINE_CHUNK_NAME.ConstructorContent]: [
    FC_DEFINE_CHUNK_NAME.ConstructorStart,
  ],
  [FC_DEFINE_CHUNK_NAME.ConstructorEnd]: [
    FC_DEFINE_CHUNK_NAME.ConstructorStart,
    FC_DEFINE_CHUNK_NAME.ConstructorContent,
  ],
  [FC_DEFINE_CHUNK_NAME.StaticVar]: [FC_DEFINE_CHUNK_NAME.Start],
  [FC_DEFINE_CHUNK_NAME.StaticMethod]: [
    FC_DEFINE_CHUNK_NAME.Start,
    FC_DEFINE_CHUNK_NAME.StaticVar,
  ],
  [FC_DEFINE_CHUNK_NAME.InsVar]: [
    FC_DEFINE_CHUNK_NAME.Start,
    FC_DEFINE_CHUNK_NAME.StaticVar,
    FC_DEFINE_CHUNK_NAME.StaticMethod,
  ],
  [FC_DEFINE_CHUNK_NAME.InsVarMethod]: [
    FC_DEFINE_CHUNK_NAME.Start,
    FC_DEFINE_CHUNK_NAME.StaticVar,
    FC_DEFINE_CHUNK_NAME.StaticMethod,
    FC_DEFINE_CHUNK_NAME.InsVar,
  ],
  [FC_DEFINE_CHUNK_NAME.InsMethod]: [
    FC_DEFINE_CHUNK_NAME.Start,
    FC_DEFINE_CHUNK_NAME.StaticVar,
    FC_DEFINE_CHUNK_NAME.StaticMethod,
    FC_DEFINE_CHUNK_NAME.InsVar,
    FC_DEFINE_CHUNK_NAME.InsVarMethod,
    FC_DEFINE_CHUNK_NAME.ConstructorEnd,
  ],
  [FC_DEFINE_CHUNK_NAME.InsPrivateMethod]: [
    FC_DEFINE_CHUNK_NAME.Start,
    FC_DEFINE_CHUNK_NAME.StaticVar,
    FC_DEFINE_CHUNK_NAME.StaticMethod,
    FC_DEFINE_CHUNK_NAME.InsVar,
    FC_DEFINE_CHUNK_NAME.InsVarMethod,
    FC_DEFINE_CHUNK_NAME.InsMethod,
    FC_DEFINE_CHUNK_NAME.ConstructorEnd,
  ],
  [FC_DEFINE_CHUNK_NAME.End]: [
    FC_DEFINE_CHUNK_NAME.Start,
    FC_DEFINE_CHUNK_NAME.StaticVar,
    FC_DEFINE_CHUNK_NAME.StaticMethod,
    FC_DEFINE_CHUNK_NAME.InsVar,
    FC_DEFINE_CHUNK_NAME.InsVarMethod,
    FC_DEFINE_CHUNK_NAME.InsMethod,
    FC_DEFINE_CHUNK_NAME.InsPrivateMethod,
    FC_DEFINE_CHUNK_NAME.ConstructorEnd,
  ],

  [COMMON_CHUNK_NAME.FileMainContent]: [
    COMMON_CHUNK_NAME.ExternalDepsImport,
    COMMON_CHUNK_NAME.InternalDepsImport,
    COMMON_CHUNK_NAME.ImportAliasDefine,
    COMMON_CHUNK_NAME.FileVarDefine,
    COMMON_CHUNK_NAME.FileUtilDefine,
    CLASS_DEFINE_CHUNK_NAME.End,
  ],
  [COMMON_CHUNK_NAME.FileExport]: [
    COMMON_CHUNK_NAME.ExternalDepsImport,
    COMMON_CHUNK_NAME.InternalDepsImport,
    COMMON_CHUNK_NAME.ImportAliasDefine,
    COMMON_CHUNK_NAME.FileVarDefine,
    COMMON_CHUNK_NAME.FileUtilDefine,
    CLASS_DEFINE_CHUNK_NAME.End,
    COMMON_CHUNK_NAME.FileMainContent,
  ],
  [COMMON_CHUNK_NAME.StyleDepsImport]: [],
  [COMMON_CHUNK_NAME.StyleCssContent]: [COMMON_CHUNK_NAME.StyleDepsImport],
  [COMMON_CHUNK_NAME.HtmlContent]: [],
};

export const COMMON_SUB_MODULE_NAME = 'index';
